@@ -2,7 +2,7 @@ import logging
 from cbv.views.base import View, TemplateView, RedirectView
 from cbv.views.dates import *
 from cbv.views.detail import DetailView
-from cbv.views.edit import CreateView, UpdateView, DeleteView
+from cbv.views.edit import FormView, CreateView, UpdateView, DeleteView
 from cbv.views.list import ListView
 
 
